Index: ash/common/wm/wm_event.h |
diff --git a/ash/common/wm/wm_event.h b/ash/common/wm/wm_event.h |
index e26ba78d46a83d1b66ef46185323a2a90b672cfa..4e0d49c22643ef7a68763c9e90b97894285db864 100644 |
--- a/ash/common/wm/wm_event.h |
+++ b/ash/common/wm/wm_event.h |
@@ -27,7 +27,6 @@ enum WMEventType { |
WM_EVENT_FULLSCREEN, |
WM_EVENT_SNAP_LEFT, |
WM_EVENT_SNAP_RIGHT, |
- WM_EVENT_DOCK, |
// A window is requested to be the given bounds. The request may or |
// may not be fulfilled depending on the requested bounds and window's |
@@ -55,18 +54,17 @@ enum WMEventType { |
// A user requested to toggle fullscreen state. |
WM_EVENT_TOGGLE_FULLSCREEN, |
- // A user requested a cycle of dock and snap left. |
+ // A user requested a cycle of snap left. |
// The way this event is processed is the current window state is used as |
// the starting state. Assuming normal window start state; if the window can |
- // be snapped left, snap it; otherwise progress to next state. If the window |
- // can be docked left, dock it; otherwise progress to next state. If the |
+ // be snapped left, snap it; otherwise progress to next state. If the |
// window can be restored; and this isn't the entry condition restore it; |
// otherwise apply the bounce animation to the window. |
- WM_EVENT_CYCLE_SNAP_DOCK_LEFT, |
+ WM_EVENT_CYCLE_SNAP_LEFT, |
- // A user requested a cycle of dock and snap right. |
- // See decription of WM_EVENT_CYCLE_SNAP_DOCK_LEFT. |
- WM_EVENT_CYCLE_SNAP_DOCK_RIGHT, |
+ // A user requested a cycle of snap right. |
+ // See decription of WM_EVENT_CYCLE_SNAP_LEFT. |
+ WM_EVENT_CYCLE_SNAP_RIGHT, |
// A user requested to center a window. |
WM_EVENT_CENTER, |